@@ -16,35 +16,28 @@
 #'
 #' @examples
 #' icc.de(prof1 = c(.59, .48, .23), prof2 = c(.52, .76, .22), input = "cor",
-#' digits = 3)
+#' digits = 2)
 #'
-icc.de<- function(prof1, prof2, input = c("cor", "score"), digits = 2){
+#' icc.de(prof1 = c(-1, -0.85, 2), prof2 = c(-0.93, 1, 1.26), input = "score",
+#' digits = 4)
+#'
+icc.de <- function(prof1, prof2, input = c("cor", "score"), digits = 2){
 
-  if(input == "cor"){
+  choice <- match.arg(input)
+  input.kind <- switch(choice, cor = 1, score = 2)
+
+  if(input.kind == 1){
     x.cor <- atanh(prof1);
     y.cor <- atanh(prof2);
     xy <- c(x.cor, y.cor);
-    yx <- c(y.cor, x.cor)}
+    yx <- c(y.cor, x.cor)
+    }
 
-  if(input == "score"){
+  if(input.kind == 2){
     xy <- c(prof1, prof2);
-    yx <- c(prof2, prof1)}
-  
+    yx <- c(prof2, prof1)
+    }
+
   iccde <- round(cor(xy, yx, use = "pairwise"), digits);
-  NAs_1 <- sum(is.na(prof1));
-  NAs_2 <- sum(is.na(prof2));
-  
-  if(NAs_1 >= 1 & NAs_2 == 0){
-    coeff <- data.frame(iccde, NAs_1)};
-  
-  if(NAs_2 >= 1 & NAs_1 == 0){
-    coeff <- data.frame(iccde, NAs_2)};
-  
-  if(NAs_1 >= 1 & NAs_2 >= 1){
-    coeff <- data.frame(iccde, NAs_1, NAs_2)};
-  
-  if(NAs_1 == 0 & NAs_2 == 0){
-    coeff <- iccde}
-  
-  return(coeff)
-}
\ No newline at end of file
+  return(iccde)
+}
